@@ -3,9 +3,10 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use base qw{ Module::Build };
+use Module::Build;
+our @ISA = qw{ Module::Build };
 
-our $VERSION = '0.050';
+our $VERSION = '0.051';
 
 use Carp;
 
@@ -79,7 +80,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
